==> com_clubmanagement_1.1.zip: site/views/members/tmpl/personalfactsheet_personaldata.php <==
<?php
//$this->people = $this->people;
//print_r($this->people);
?>
	<table style="width: 500px; float: left;" id="personalFactsheet">
		<caption><?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET');?></caption>
		<tr>
			<th><?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET_NAME');?></th>
			<td><?php echo $this->people->name;?> <?php echo $this->people->surname;?></td>
		</tr>
		<tr>
			<th><?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET_AGE');?>/<?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET_BIRTHDAY');?></th>
			<td><?php echo $this->people->age;?> / <?php echo JFactory::getDate(strtotime($this->people->birthday))->toFormat(JText::_('%Y-%M-%D'));?></td>
		</tr>
		<tr>
			<th><?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET_ADDRESS');?></th>
			<td>
				<address><?php
						echo $this->people->name." ".$this->people->surname."<br/>";
						echo $this->people->address."<br/>";
						echo $this->people->country." ".$this->people->zipcode." ".$this->people->city;
				?></address>
			</td>
		</tr>
	</table>
<?php
$tmp = str_replace(array(JURI::root(), '/'), array(JPATH_ROOT, DS), JURI::root().$this->people->passportPhotograph);
if (!empty($this->people->passportPhotograph) && $this->params->get('show_passportPhotograph')) {?>
	<img style="text-align: right; display: block; float: right; width: 160px; " class="passportPhotograph" src="<?php echo JURI::root(TRUE).$this->people->passportPhotograph;?>" alt="<?php echo $this->people->name_complete;?>" title="<?php echo $this->people->name_complete;?>"/>
<?php
}
?>
	<div style="clear: both;"></div>

==> com_clubmanagement_1.3.zip: site/views/members/tmpl/personalfactsheet_personaldata.php <==
<?php
//$this->people = $this->people;
//print_r($this->people);
//var_dump($this->params->get('show_birthday'));
?>
	<table style="width: 500px; float: left;" id="personalFactsheet">
		<caption><?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET');?></caption>
		<tr>
			<th><?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET_NAME');?></th>
			<td><?php echo $this->people->name;?> <?php echo $this->people->surname;?></td>
		</tr>
<?php
if($this->params->get('show_birthday')) {
?>
		<tr>
			<th><?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET_AGE');?>/<?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET_BIRTHDAY');?></th>
			<td><?php echo $this->people->age;?> / <?php echo JFactory::getDate(strtotime($this->people->birthday))->toFormat(JText::_('%Y-%M-%D'));?></td>
		</tr>
<?php
}
?>
<?php
if($this->params->get('show_address')) {
?>
		<tr>
			<th><?php echo JText::_('COM_CLUBMANAGEMENT_PERSONALFACTSHEET_ADDRESS');?></th>
			<td>
				<address><?php
						echo $this->people->name." ".$this->people->surname."<br/>";
						echo $this->people->address."<br/>";
						echo $this->people->country." ".$this->people->zipcode." ".$this->people->city;
				?></address>
			</td>
		</tr>
<?php
}
?>
	</table>
<?php
$tmp = str_replace(array(JURI::root(), '/'), array(JPATH_ROOT, DS), JURI::root().$this->people->passportPhotograph);
if (!empty($this->people->passportPhotograph) && $this->params->get('show_passportPhotograph')) {?>
	<img style="text-align: right; display: block; float: right; width: 160px; " class="passportPhotograph" src="<?php echo JURI::root(TRUE).$this->people->passportPhotograph;?>" alt="<?php echo $this->people->name_complete;?>" title="<?php echo $this->people->name_complete;?>"/>
<?php
}
?>
	<div style="clear: both;"></div>
